@@ -4,7 +4,7 @@
 from django.forms import ChoiceField, Select, ValidationError
 
 class HierarchicalSelect(Select):
-	jquery_namespace = '(django.jQuery | $)'
+	jquery_namespace = 'django.jQuery'
 	
 	def __init__(self, *args, **kwargs):
 		self.jquery_namespace = kwargs.pop('jquery_namespace', self.jquery_namespace)
